==> platform-client-v2-40.0.0-sources.jar: com/mypurecloud/sdk/v2/model/Chat.java <==
package com.mypurecloud.sdk.v2.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
/**
 * Chat
 */

public class Chat  implements Serializable {
  
  private String jabberId = null;

  
  /**
   **/
  public Chat jabberId(String jabberId) {
    this.jabberId = jabberId;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "")
  @JsonProperty("jabberId")
  public String getJabberId() {
    return jabberId;
  }
  public void setJabberId(String jabberId) {
    this.jabberId = jabberId;
  }

  

  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    Chat chat = (Chat) o;
    return Objects.equals(this.jabberId, chat.jabberId);
  }

  @Override
  public int hashCode() {
    return Objects.hash(jabberId);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class Chat {\n");
    
    sb.append("    jabberId: ").append(toIndentedString(jabberId)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> platform-client-v2-203.0.0-sources.jar: com/mypurecloud/sdk/v2/model/Chat.java <==
package com.mypurecloud.sdk.v2.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.deser.std.StdDeserializer;
import java.util.Objects;
import java.util.ArrayList;
import java.io.IOException;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
/**
 * Chat
 */

public class Chat  implements Serializable {
  
  private String jabberId = null;

  
  /**
   **/
  public Chat jabberId(String jabberId) {
    this.jabberId = jabberId;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "")
  @JsonProperty("jabberId")
  public String getJabberId() {
    return jabberId;
  }
  public void setJabberId(String jabberId) {
    this.jabberId = jabberId;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    Chat chat = (Chat) o;

    return Objects.equals(this.jabberId, chat.jabberId);
  }

  @Override
  public int hashCode() {
    return Objects.hash(jabberId);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class Chat {\n");
    
    sb.append("    jabberId: ").append(toIndentedString(jabberId)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
